==> create-fly-1.21.8-6.0.8-2-sources.jar: com/zurrtum/create/client/catnip/render/ShadedBlockSbbBuilder.java <==
package com.zurrtum.create.client.catnip.render;

import com.mojang.blaze3d.vertex.VertexFormat;
import it.unimi.dsi.fastutil.ints.IntArrayList;
import it.unimi.dsi.fastutil.ints.IntList;
import net.minecraft.class_287;
import net.minecraft.class_290;
import net.minecraft.class_4587;
import net.minecraft.class_4588;
import net.minecraft.class_777;
import net.minecraft.class_9799;
import net.minecraft.class_9801;

@Deprecated(forRemoval = true)
public class ShadedBlockSbbBuilder implements class_4588 {
    protected static final class_9799 BYTE_BUFFER_BUILDER = new class_9799(512);
    protected class_287 bufferBuilder;
    protected final IntList shadeSwapVertices = new IntArrayList();
    protected boolean currentShade;
    protected boolean invertFakeNormal;

    public static ShadedBlockSbbBuilder create() {
        return new ShadedBlockSbbBuilder();
    }

    public static ShadedBlockSbbBuilder createForPonder() {
        ShadedBlockSbbBuilder builder = new ShadedBlockSbbBuilder();
        builder.invertFakeNormal = true;
        return builder;
    }

    public void begin() {
        bufferBuilder = new class_287(BYTE_BUFFER_BUILDER, VertexFormat.class_5596.field_27382, class_290.field_1590);
        shadeSwapVertices.clear();
        currentShade = true;
    }

    public SuperByteBuffer end() {
        class_9801 data = bufferBuilder.method_60794();
        TemplateMesh mesh;

        if (data != null) {
            mesh = new MutableTemplateMesh(data).toImmutable();
            data.close();
        } else {
            mesh = new TemplateMesh(0);
        }

        return new ShadeSeparatingSuperByteBuffer(mesh, shadeSwapVertices.toIntArray(), invertFakeNormal);
    }

    public class_287 unwrap(boolean shade) {
        prepareForGeometry(shade);
        return bufferBuilder;
    }

    private void prepareForGeometry(boolean shade) {
        if (shade != currentShade) {
            shadeSwapVertices.add(bufferBuilder.field_1554);
            currentShade = shade;
        }
    }

    protected void prepareForGeometry(class_777 quad) {
        prepareForGeometry(quad.comp_3725());
    }

    @Override
    public void method_22919(class_4587.class_4665 pose, class_777 quad, float red, float green, float blue, float alpha, int packedLight, int packedOverlay) {
        prepareForGeometry(quad);
        bufferBuilder.method_22919(pose, quad, red, green, blue, alpha, packedLight, packedOverlay);
    }

    @Override
    public void method_22920(
        class_4587.class_4665 pose,
        class_777 quad,
        float[] brightnesses,
        float red,
        float green,
        float blue,
        float alpha,
        int[] lights,
        int overlay,
        boolean readExistingColor
    ) {
        prepareForGeometry(quad);
        bufferBuilder.method_22920(pose, quad, brightnesses, red, green, blue, alpha, lights, overlay, readExistingColor);
    }

    @Override
    public class_4588 method_22912(float x, float y, float z) {
        throw new UnsupportedOperationException("ShadedBlockSbbBuilder only supports putBulkData!");
    }

    @Override
    public class_4588 method_1336(int red, int green, int blue, int alpha) {
        throw new UnsupportedOperationException("ShadedBlockSbbBuilder only supports putBulkData!");
    }

    @Override
    public class_4588 method_22913(float u, float v) {
        throw new UnsupportedOperationException("ShadedBlockSbbBuilder only supports putBulkData!");
    }

    @Override
    public class_4588 method_60796(int u, int v) {
        throw new UnsupportedOperationException("ShadedBlockSbbBuilder only supports putBulkData!");
    }

    @Override
    public class_4588 method_22921(int u, int v) {
        throw new UnsupportedOperationException("ShadedBlockSbbBuilder only supports putBulkData!");
    }

    @Override
    public class_4588 method_22914(float x, float y, float z) {
        throw new UnsupportedOperationException("ShadedBlockSbbBuilder only supports putBulkData!");
    }
}

==> create-fly-1.21.11-6.0.8-2-sources.jar: com/zurrtum/create/client/catnip/render/ShadedBlockSbbBuilder.java <==
package com.zurrtum.create.client.catnip.render;

import com.mojang.blaze3d.vertex.*;
import it.unimi.dsi.fastutil.ints.IntArrayList;
import it.unimi.dsi.fastutil.ints.IntList;
import net.minecraft.class_287;
import net.minecraft.class_290;
import net.minecraft.class_4587;
import net.minecraft.class_4588;
import net.minecraft.class_777;
import net.minecraft.class_9799;
import net.minecraft.class_9801;

@Deprecated(forRemoval = true)
public class ShadedBlockSbbBuilder implements class_4588 {
    protected static final class_9799 BYTE_BUFFER_BUILDER = new class_9799(512);
    protected class_287 bufferBuilder;
    protected final IntList shadeSwapVertices = new IntArrayList();
    protected boolean currentShade;
    protected boolean invertFakeNormal;

    public static ShadedBlockSbbBuilder create() {
        return new ShadedBlockSbbBuilder();
    }

    public static ShadedBlockSbbBuilder createForPonder() {
        ShadedBlockSbbBuilder builder = new ShadedBlockSbbBuilder();
        builder.invertFakeNormal = true;
        return builder;
    }

    public void begin() {
        bufferBuilder = new class_287(BYTE_BUFFER_BUILDER, VertexFormat.class_5596.field_27382, class_290.field_1590);
        shadeSwapVertices.clear();
        currentShade = true;
    }

    public SuperByteBuffer end() {
        class_9801 data = bufferBuilder.method_60794();
        TemplateMesh mesh;

        if (data != null) {
            mesh = new MutableTemplateMesh(data).toImmutable();
            data.close();
        } else {
            mesh = new TemplateMesh(0);
        }

        return new ShadeSeparatingSuperByteBuffer(mesh, shadeSwapVertices.toIntArray(), invertFakeNormal);
    }

    public class_287 unwrap(boolean shade) {
        prepareForGeometry(shade);
        return bufferBuilder;
    }

    private void prepareForGeometry(boolean shade) {
        if (shade != currentShade) {
            shadeSwapVertices.add(bufferBuilder.field_1554);
            currentShade = shade;
        }
    }

    protected void prepareForGeometry(class_777 quad) {
        prepareForGeometry(quad.comp_3725());
    }

    @Override
    public void method_22919(
        class_4587.class_4665 pose,
        class_777 quad,
        float red,
        float green,
        float blue,
        float alpha,
        int packedLight,
        int packedOverlay
    ) {
        prepareForGeometry(quad);
        bufferBuilder.method_22919(pose, quad, red, green, blue, alpha, packedLight, packedOverlay);
    }

    @Override
    public void method_22920(
        class_4587.class_4665 pose,
        class_777 quad,
        float[] brightnesses,
        float red,
        float green,
        float blue,
        float alpha,
        int[] lights,
        int overlay
    ) {
        prepareForGeometry(quad);
        bufferBuilder.method_22920(pose, quad, brightnesses, red, green, blue, alpha, lights, overlay);
    }

    @Override
    public class_4588 method_22912(float x, float y, float z) {
        throw new UnsupportedOperationException("ShadedBlockSbbBuilder only supports putBulkData!");
    }

    @Override
    public class_4588 method_39415(int color) {
        throw new UnsupportedOperationException("ShadedBlockSbbBuilder only supports putBulkData!");
    }

    @Override
    public class_4588 method_1336(int red, int green, int blue, int alpha) {
        throw new UnsupportedOperationException("ShadedBlockSbbBuilder only supports putBulkData!");
    }

    @Override
    public class_4588 method_22913(float u, float v) {
        throw new UnsupportedOperationException("ShadedBlockSbbBuilder only supports putBulkData!");
    }

    @Override
    public class_4588 method_60796(int u, int v) {
        throw new UnsupportedOperationException("ShadedBlockSbbBuilder only supports putBulkData!");
    }

    @Override
    public class_4588 method_22921(int u, int v) {
        throw new UnsupportedOperationException("ShadedBlockSbbBuilder only supports putBulkData!");
    }

    @Override
    public class_4588 method_22914(float x, float y, float z) {
        throw new UnsupportedOperationException("ShadedBlockSbbBuilder only supports putBulkData!");
    }

    @Override
    public class_4588 method_75298(float width) {
        throw new UnsupportedOperationException("ShadedBlockSbbBuilder only supports putBulkData!");
    }
}
